@@ -190,36 +190,8 @@ static int sdla_te3_polling(sdla_fe_t *fe)
 	int prev_status=fe->fe_status;
 	sdla_t	*card = (sdla_t*)fe->card;
 
-
 	err=sdla_te3_read_alarms(fe, WAN_FE_ALARM_READ|WAN_FE_ALARM_UPDATE);
 	
-	DEBUG_TEST("%s: Polling prev_state = %i newsate=%i timeout=%i diff=%i\n",
-				fe->name,prev_status,fe->fe_status,fe->fe_cfg.cfg.te3_cfg.disc_cfg_timeout,
-				(SYSTEM_TICKS-fe->fe_param.te3.disc_timeout)/HZ);
-
-	if (fe->fe_cfg.media == WAN_MEDIA_DS3){
-		if (1 || fe->fe_cfg.cfg.te3_cfg.disc_cfg_timeout) {
-			if (prev_status == FE_CONNECTED) {
-				if (fe->fe_status == FE_DISCONNECTED) {
-					DEBUG_TEST("%s: FE_DISCONNECTED checking timeout %lu\n",
-						fe->name,	(SYSTEM_TICKS-fe->fe_param.te3.disc_timeout));
-		
-					if (1 || (SYSTEM_TICKS-fe->fe_param.te3.disc_timeout) < (fe->fe_cfg.cfg.te3_cfg.disc_cfg_timeout*HZ)) {
-						DEBUG_EVENT("%s: FE Disconnect - resetting FE %i\n",
-									card->devname,fe->fe_cfg.cfg.te3_cfg.disc_cfg_timeout);
-						sdla_te3_config(fe);
-					}
-				}
-			} else {
-				if (fe->fe_status == FE_CONNECTED) {
-					fe->fe_param.te3.disc_timeout=SYSTEM_TICKS;
-					DEBUG_TEST("%s: FE_CONNECTED resetting timeout %lu\n",
-						fe->name,	(SYSTEM_TICKS-fe->fe_param.te3.disc_timeout)/HZ);
-				}
-			}
-		}
-	}
-
 	return err;
 }
 
@@ -1290,8 +1262,17 @@ static int sdla_te3_config(void *p_fe)
 
 	card->hw_iface.getcfg(card->hw, SDLA_ADAPTERSUBTYPE, &adptr_subtype);
 	
+	/* Read the part number */
 	data = READ_REG(0x02);
-	
+	if (data != 0x07) {
+		DEBUG_EVENT("%s: Invalid T3/E3 Front End Chip Part number (%X)\n",
+				fe->name, data);
+		return -EINVAL;
+	}
+
+	/* Reset data variable */
+	data = 0x00;
+
 	/* configure Line Interface Unit */
 	if (card->adptr_subtype == AFT_SUBTYPE_NORMAL){
 		sdla_te3_liu_config(fe, &te3_cfg->liu_cfg, fe->name);
@@ -1368,7 +1349,11 @@ static int sdla_te3_config(void *p_fe)
 				fe->name,fe_cfg->frame);
 		return -EINVAL;
 	}
+
+	/* NC: Internal LOS can fail and get stuck do not use it */
+#if 0
 	data |= BIT_OPMODE_INTERNAL_LOS;
+#endif
 	data |= (BIT_OPMODE_TIMREFSEL1 | BIT_OPMODE_TIMREFSEL0);
 	WRITE_REG(REG_OPMODE, data);
 
